# Mypy Type Check Coverage Summary

Summary from index
File | Imprecision | Lines
--- | --- | ---
Total | 17.77% imprecise | 709 LOC
hatch_ci | 0.00% imprecise | 2 LOC
hatch_ci.__main__ | 33.75% imprecise | 80 LOC
hatch_ci.common | 0.00% imprecise | 1 LOC
hatch_ci.hooks | 37.50% imprecise | 8 LOC
hatch_ci.scm | 9.30% imprecise | 258 LOC
hatch_ci.tools | 22.06% imprecise | 281 LOC
hatch_ci.version_hook | 12.66% imprecise | 79 LOC